@@ -105,6 +105,8 @@ class DateTest(unittest.TestCase):
                           self.conv.from_string, "40-10-2005")
         self.assertRaises(ValidationError,
                           self.conv.from_string, "30-02-2005")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, '01-01-1899')
 
     def testAsStringBR(self):
         if not set_locale(locale.LC_TIME, 'pt_BR'):
@@ -124,6 +126,7 @@ class DateTest(unittest.TestCase):
                           self.conv.from_string, "40/10/2005")
         self.assertRaises(ValidationError,
                           self.conv.from_string, "30/02/2005")
+        self.assertRaises(ValidationError, self.conv.from_string, '01/01/1899')
 
     def testAsStringPortugueseBrazil(self):
         if not set_locale(locale.LC_TIME, 'Portuguese_Brazil.1252'):
@@ -131,6 +134,11 @@ class DateTest(unittest.TestCase):
 
         self.assertEqual(self.conv.as_string(self.date), "12/02/1979")
 
+    def testInvalid(self):
+        self.assertRaises(ValidationError, self.conv.as_string,
+                          datetime.date(1899, 1, 1))
+
+
 class CurrencyTest(unittest.TestCase):
     def setUp(self):
         set_locale(locale.LC_ALL, 'C')
@@ -139,6 +147,15 @@ class CurrencyTest(unittest.TestCase):
     def tearDown(self):
         set_locale(locale.LC_ALL, 'C')
 
+    def testFormat(self):
+        self.assertEqual(currency('100').format(), '$100')
+        self.assertEqual(currency('199').format(), '$199')
+
+        self.assertEqual(currency('1.99').format(), '$1.99')
+        self.assertEqual(currency('1.994').format(), '$1.99')
+        self.assertEqual(currency('1.995').format(), '$1.99')
+        self.assertEqual(currency('1.996').format(), '$1.99')
+
     def testFormatBR(self):
         if not set_locale(locale.LC_ALL, 'pt_BR'):
             return
